@@ -12,6 +12,20 @@ require Time::Local;
 
 __PACKAGE__->attr('epoch');
 
+# Days and months
+my @DAYS   = qw/Sun Mon Tue Wed Thu Fri Sat/;
+my @MONTHS = qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
+
+# Reverse months
+my %MONTHS;
+{
+    my $i = 0;
+    for my $month (@MONTHS) {
+        $MONTHS{$month} = $i;
+        $i++;
+    }
+}
+
 sub new {
     my $self = shift->SUPER::new();
     $self->parse(@_);
@@ -25,10 +39,8 @@ sub new {
 sub parse {
     my ($self, $date) = @_;
 
-    $self = $self->new unless ref $self;
-
     # Shortcut
-    return unless defined $date;
+    return $self unless defined $date;
 
     # epoch - 784111777
     if ($date =~ /^\d+$/) {
@@ -38,22 +50,17 @@ sub parse {
 
     # Remove spaces, weekdays and timezone
     $date =~ s/^\s+//;
-    $date =~ s/^(?:Sun|Mon|Tue|Wed|Thu|Fri|Sat)[a-z]*,?\s*//i;
+    my $re = join '|', @DAYS;
+    $date =~ s/^(?:$re)[a-z]*,?\s*//i;
     $date =~ s/GMT\s*$//i;
     $date =~ s/\s+$//;
 
     my ($day, $month, $year, $hour, $minute, $second);
-    my $months = {};
-    my $i      = 0;
-    for my $m (qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/) {
-        $months->{$m} = $i;
-        $i++;
-    }
 
     # RFC822/1123 - Sun, 06 Nov 1994 08:49:37 GMT
     if ($date =~ /^(\d+)\s+(\w+)\s+(\d+)\s+(\d+):(\d+):(\d+)$/) {
         $day    = $1;
-        $month  = $months->{$2};
+        $month  = $MONTHS{$2};
         $year   = $3;
         $hour   = $4;
         $minute = $5;
@@ -63,7 +70,7 @@ sub parse {
     # RFC850/1036 - Sunday, 06-Nov-94 08:49:37 GMT
     elsif ($date =~ /^(\d+)-(\w+)-(\d+)\s+(\d+):(\d+):(\d+)$/) {
         $day    = $1;
-        $month  = $months->{$2};
+        $month  = $MONTHS{$2};
         $year   = $3;
         $hour   = $4;
         $minute = $5;
@@ -72,7 +79,7 @@ sub parse {
 
     # ANSI C asctime() - Sun Nov  6 08:49:37 1994
     elsif ($date =~ /^(\w+)\s+(\d+)\s+(\d+):(\d+):(\d+)\s+(\d+)$/) {
-        $month  = $months->{$1};
+        $month  = $MONTHS{$1};
         $day    = $2;
         $hour   = $3;
         $minute = $4;
@@ -81,7 +88,7 @@ sub parse {
     }
 
     # Invalid format
-    else { return undef }
+    else { return $self }
 
     my $epoch;
 
@@ -91,7 +98,7 @@ sub parse {
           Time::Local::timegm($second, $minute, $hour, $day, $month, $year);
     };
 
-    return undef if $@ || $epoch < 0;
+    return $self if $@ || $epoch < 0;
 
     $self->epoch($epoch);
 
@@ -99,20 +106,17 @@ sub parse {
 }
 
 sub to_string {
-    my $self = shift;
-    my $epoch = shift || $self->{epoch};
+    my $self  = shift;
+    my $epoch = $self->epoch;
 
     $epoch = time unless defined $epoch;
 
     my ($second, $minute, $hour, $mday, $month, $year, $wday) = gmtime $epoch;
 
-    my $days   = [qw/Sun Mon Tue Wed Thu Fri Sat/];
-    my $months = [qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/];
-
     # Format
     return sprintf(
         "%s, %02d %s %04d %02d:%02d:%02d GMT",
-        $days->[$wday], $mday, $months->[$month], $year + 1900,
+        $DAYS[$wday], $mday, $MONTHS[$month], $year + 1900,
         $hour, $minute, $second
     );
 }
@@ -143,14 +147,13 @@ L<Mojo::Date> implements HTTP date and time functions according to RFC2616.
 
 =head1 ATTRIBUTES
 
+L<Mojo::Date> implements the following attributes.
+
 =head2 C<epoch>
 
     my $epoch = $date->epoch;
     $date     = $date->epoch(784111777);
 
-Returns epoch seconds if called without arguments.
-Returns the invocant if called with arguments.
-
 =head1 METHODS
 
 L<Mojo::Date> inherits all methods from L<Mojo::Base> and implements the
@@ -158,15 +161,13 @@ following new ones.
 
 =head2 C<new>
 
+    my $date = Mojo::Date->new;
     my $date = Mojo::Date->new($string);
 
 =head2 C<parse>
 
     $date = $date->parse('Sun Nov  6 08:49:37 1994');
 
-Returns the invocant if the given date could be parsed successfully.
-Returns false otherwise.
-
 Parsable formats include:
 
     - Epoch format (784111777)
@@ -178,6 +179,4 @@ Parsable formats include:
 
     my $string = $date->to_string;
 
-Returns a valid HTTP date according to RFC 822.
-
 =cut
