@@ -10,7 +10,7 @@ use base 'Mojo::Transaction';
 use Mojo::Message::Request;
 use Mojo::Message::Response;
 
-__PACKAGE__->attr('continued');
+__PACKAGE__->attr([qw/continued handler_cb continue_handler_cb/]);
 __PACKAGE__->attr(req => sub { Mojo::Message::Request->new });
 __PACKAGE__->attr(res => sub { Mojo::Message::Response->new });
 
@@ -20,12 +20,9 @@ __PACKAGE__->attr(_started => sub {time});
 
 # What's a wedding?  Webster's dictionary describes it as the act of removing
 # weeds from one's garden.
-sub client_connect {
+sub client_connected {
     my $self = shift;
 
-    # Connect
-    $self->state('connect');
-
     # Connection header
     unless ($self->req->headers->connection) {
         if ($self->keep_alive || $self->kept_alive) {
@@ -40,12 +37,6 @@ sub client_connect {
     $self->req->headers->user_agent('Mozilla/5.0 (compatible; Mojo; Perl)')
       unless $self->req->headers->user_agent;
 
-    return $self;
-}
-
-sub client_connected {
-    my $self = shift;
-
     # We might have to handle 100 Continue
     $self->_continue($self->continue_timeout)
       if ($self->req->headers->expect || '') =~ /100-continue/;
@@ -81,6 +72,15 @@ sub client_get_chunk {
     $chunk = $self->req->get_start_line_chunk($self->_offset)
       if $self->is_state('write_start_line');
 
+    # Written
+    my $written = defined $chunk ? length $chunk : 0;
+    $self->_to_write($self->_to_write - $written);
+    $self->_offset($self->_offset + $written);
+
+    # Chunked
+    $self->_to_write(1)
+      if $self->req->is_chunked && $self->is_state('write_body');
+
     return $chunk;
 }
 
@@ -98,7 +98,7 @@ sub client_info {
         $port   = $proxy->port || 80;
     }
 
-    return ($scheme, $host, $port);
+    return {host => $host, port => $port, scheme => $scheme};
 }
 
 sub client_leftovers {
@@ -251,20 +251,6 @@ sub client_spin {
     return $self;
 }
 
-sub client_written {
-    my ($self, $written) = @_;
-
-    # Written
-    $self->_to_write($self->_to_write - $written);
-    $self->_offset($self->_offset + $written);
-
-    # Chunked
-    $self->_to_write(1)
-      if $self->req->is_chunked && $self->is_state('write_body');
-
-    return $self;
-}
-
 sub keep_alive {
     my ($self, $keep_alive) = @_;
 
@@ -299,25 +285,6 @@ sub keep_alive {
     return $self->{keep_alive};
 }
 
-sub new_delete { shift->_builder('DELETE', @_) }
-sub new_get    { shift->_builder('GET',    @_) }
-sub new_head   { shift->_builder('HEAD',   @_) }
-sub new_post   { shift->_builder('POST',   @_) }
-sub new_put    { shift->_builder('PUT',    @_) }
-
-sub server_accept {
-    my $self = shift;
-
-    # Reading
-    $self->state('read');
-
-    # We identify ourself
-    $self->res->headers->server('Mojo (Perl)')
-      unless $self->res->headers->server;
-
-    return $self;
-}
-
 sub server_get_chunk {
     my $self = shift;
 
@@ -344,18 +311,25 @@ sub server_get_chunk {
     $chunk = $self->res->get_start_line_chunk($self->_offset)
       if $self->is_state('write_start_line');
 
+    # Written
+    my $written = defined $chunk ? length $chunk : 0;
+    $self->_to_write($self->_to_write - $written);
+    $self->_offset($self->_offset + $written);
+
+    # Chunked
+    $self->_to_write(1)
+      if $self->res->is_chunked && $self->is_state('write_body');
+
+    # Done early
+    if ($self->is_state('write_body') && $self->_to_write <= 0) {
+        $self->req->is_state('done_with_leftovers')
+          ? $self->state('done_with_leftovers')
+          : $self->state('done');
+    }
+
     return $chunk;
 }
 
-sub server_handled {
-    my $self = shift;
-
-    # Handled and writing now
-    $self->state('write');
-
-    return $self;
-}
-
 sub server_read {
     my ($self, $chunk) = @_;
 
@@ -365,23 +339,39 @@ sub server_read {
     # Expect 100 Continue?
     if ($self->req->content->is_state('body') && !defined $self->continued) {
         if (($self->req->headers->expect || '') =~ /100-continue/i) {
-            $self->state('handle_continue');
+
+            # Writing
+            $self->state('write');
+
+            # Continue handler callback
+            $self->continue_handler_cb->($self);
             $self->continued(0);
         }
     }
 
     # EOF
     if ((length $chunk == 0) || $self->req->is_finished) {
-        $self->state('handle_request');
+
+        # Writing
+        $self->state('write');
+
+        # Handler callback
+        $self->handler_cb->($self);
     }
 
     return $self;
 }
 
 sub server_spin {
-
     my $self = shift;
 
+    # We identify ourself
+    $self->res->headers->server('Mojo (Perl)')
+      unless $self->res->headers->server;
+
+    # Reading
+    $self->state('read') if $self->is_state('start');
+
     # Writing
     if ($self->is_state('write')) {
 
@@ -456,47 +446,6 @@ sub server_spin {
     return $self;
 }
 
-sub server_written {
-    my ($self, $written) = @_;
-
-    # Written
-    $self->_to_write($self->_to_write - $written);
-    $self->_offset($self->_offset + $written);
-
-    # Chunked
-    $self->_to_write(1)
-      if $self->res->is_chunked && $self->is_state('write_body');
-
-    # Done early
-    if ($self->is_state('write_body') && $self->_to_write <= 0) {
-        $self->req->is_state('done_with_leftovers')
-          ? $self->state('done_with_leftovers')
-          : $self->state('done');
-    }
-
-    return $self;
-}
-
-sub _builder {
-    my $class = shift;
-    my $self  = $class->new;
-    my $req   = $self->req;
-
-    # Method
-    $req->method(shift);
-
-    # URL
-    $req->url->parse(shift);
-
-    # Headers
-    my $headers = ref $_[0] eq 'HASH' ? $_[0] : {@_};
-    for my $name (keys %$headers) {
-        $req->headers->header($name, $headers->{$name});
-    }
-
-    return $self;
-}
-
 # Replace client response after receiving 100 Continue
 sub _new_response {
     my $self = shift;
@@ -548,11 +497,21 @@ L<Mojo::Transaction::Single> is a container for HTTP transactions.
 L<Mojo::Transaction::Single> inherits all attributes from
 L<Mojo::Transaction> and implements the following new ones.
 
+=head2 C<continue_handler_cb>
+
+    my $cb = $tx->continue_handler_cb;
+    $tx    = $tx->continue_handler_cb(sub {...});
+
 =head2 C<continued>
 
     my $continued = $tx->continued;
     $tx           = $tx->continued(1);
 
+=head2 C<handler_cb>
+
+    my $cb = $tx->handler_cb;
+    $tx    = $tx->handler_cb(sub {...});
+
 =head2 C<keep_alive>
 
     my $keep_alive = $tx->keep_alive;
@@ -573,10 +532,6 @@ L<Mojo::Transaction> and implements the following new ones.
 L<Mojo::Transaction::Single> inherits all methods from L<Mojo::Transaction>
 and implements the following new ones.
 
-=head2 C<client_connect>
-
-    $tx = $tx->client_connect;
-
 =head2 C<client_connected>
 
     $tx = $tx->client_connected;
@@ -587,7 +542,7 @@ and implements the following new ones.
 
 =head2 C<client_info>
 
-    my ($scheme, $host, $port) = $tx->client_info;
+    my $info = $tx->client_info;
 
 =head2 C<client_leftovers>
 
@@ -601,67 +556,10 @@ and implements the following new ones.
 
     $tx = $tx->client_spin;
 
-=head2 C<client_written>
-
-    $tx = $tx->client_written($length);
-
-=head2 C<new_delete>
-
-    my $tx = Mojo::Transaction::Single->new_delete('http://127.0.0.1',
-        User-Agent => 'Mojo'
-    );
-    my $tx = Mojo::Transaction::Single->new_delete('http://127.0.0.1', {
-        User-Agent => 'Mojo'
-    });
-
-=head2 C<new_get>
-
-    my $tx = Mojo::Transaction::Single->new_get('http://127.0.0.1',
-        User-Agent => 'Mojo'
-    );
-    my $tx = Mojo::Transaction::Single->new_get('http://127.0.0.1', {
-        User-Agent => 'Mojo'
-    });
-
-=head2 C<new_head>
-
-    my $tx = Mojo::Transaction::Single->new_head('http://127.0.0.1',
-        User-Agent => 'Mojo'
-    );
-    my $tx = Mojo::Transaction::Single->new_head('http://127.0.0.1', {
-        User-Agent => 'Mojo'
-    });
-
-=head2 C<new_post>
-
-    my $tx = Mojo::Transaction::Single::Single->new_post('http://127.0.0.1',
-        User-Agent => 'Mojo'
-    );
-    my $tx = Mojo::Transaction::Single::Single->new_post('http://127.0.0.1', {
-        User-Agent => 'Mojo'
-    });
-
-=head2 C<new_put>
-
-    my $tx = Mojo::Transaction::Single->new_put('http://127.0.0.1',
-        User-Agent => 'Mojo'
-    );
-    my $tx = Mojo::Transaction::Single->new_put('http://127.0.0.1', {
-        User-Agent => 'Mojo'
-    });
-
-=head2 C<server_accept>
-
-    $tx = $tx->server_accept;
-
 =head2 C<server_get_chunk>
 
     my $chunk = $tx->server_get_chunk;
 
-=head2 C<server_handled>
-
-    $tx = $tx->server_handled;
-
 =head2 C<server_read>
 
     $tx = $tx->server_read($chunk);
@@ -670,8 +568,4 @@ and implements the following new ones.
 
     $tx = $tx->server_spin;
 
-=head2 C<server_written>
-
-    $tx = $tx->server_written($bytes);
-
 =cut
